@@ -528,18 +528,6 @@ reset_progress_dialog (NcbOperation *operation)
 	ncb_progress_dialog_clear (NCB_PROGRESS_DIALOG (operation->priv->progress_dialog));
 }
 
-static void
-do_eject (NcbOperation *operation)
-
-{
-	NautilusBurnDrive *drive;
-
-	drive = ncb_selection_peek_drive (operation->priv->selection);
-	if (drive != NULL) {
-		nautilus_burn_drive_eject (drive);
-	}
-}
-
 static void
 do_make_another (NcbOperation *operation)
 {
@@ -569,12 +557,6 @@ finish_progress_dialog (NcbOperation *operation)
 	drive = ncb_selection_peek_drive (operation->priv->selection);
 
 	ncb_progress_dialog_done (NCB_PROGRESS_DIALOG (operation->priv->progress_dialog));
-
-	/* If target is not a disc then don't offer eject */
-	if (nautilus_burn_drive_get_device (drive) == NULL) {
-		gtk_dialog_set_response_sensitive (GTK_DIALOG (operation->priv->progress_dialog),
-						   GTK_RESPONSE_REJECT, FALSE);
-	}
 }
 
 static gboolean
@@ -1473,7 +1455,7 @@ prepare_tracks (NcbOperation *operation)
 
 	/* Default flags */
 	operation->priv->record_flags = 0;
-	if (FALSE) {
+	if (TRUE) {
 		operation->priv->record_flags |= NAUTILUS_BURN_RECORDER_WRITE_EJECT;
 	}
 	if (operation->priv->dummy) {
@@ -1727,10 +1709,6 @@ progress_dialog_response (GtkWidget    *dialog,
 		do_make_another (operation);
 	}
 
-	if (response_id == GTK_RESPONSE_REJECT) {
-		do_eject (operation);
-	}
-
 	if (response_id == GTK_RESPONSE_CLOSE) {
 		gtk_widget_hide (dialog);
 		do_callback (operation);
